@@ -1,6 +1,6 @@
-#' Creates an animated treemap.
+#' Creates a treemap for a given year
 #' @export
-#' @return Creates an \code{HTML} file in the working directory with a tree map visualization.
+#' @return Creates an \code{HTML} file with a treemap visualization for a given year.
 #' @param ORIGIN is the country code of origin (e.g. "chl" for Chile)
 #' @param DESTINATION is the country code of origin (e.g. "chn" for China)
 #' @param VARIABLE is the variable to visualize and it can be "imports", "exports" or "exchange" (trade exchange)
@@ -40,10 +40,6 @@ treemap <- function(ORIGIN, DESTINATION, VARIABLE, CLASSIFICATION, YEAR) {
       }
     }
 
-    width = 1000
-    height = 600
-
-    #grouped_val <- ifelse(GROUPED == "yes", 0, ifelse(GROUPED == "no", 1, message("*** Input only allows \"yes\" and \"no\" ***")))
     grouped_val = 1
     variablecol <- ifelse(VARIABLE == "imports", "import_val",
                           ifelse(VARIABLE == "exports", "export_val",
